@@ -2,12 +2,22 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #pragma once
-
+#include <QObject>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <akonadi_version.h>
+#if AKONADI_VERSION >= QT_VERSION_CHECK(5, 19, 40)
+#include <Akonadi/ContactsFilterProxyModel>
+#include <Akonadi/ContactsTreeModel>
+#else
 #include <Akonadi/Contact/ContactsFilterProxyModel>
 #include <Akonadi/Contact/ContactsTreeModel>
+#endif
+#else
+#include <Akonadi/ContactsFilterProxyModel>
+#include <Akonadi/ContactsTreeModel>
+#endif
 #include <QObject>
 #include <QSortFilterProxyModel>
-#include <akonadi_version.h>
 #include <Akonadi/EntityMimeTypeFilterModel>
 
 class QSortFilterProxyModel;
