@@ -15,9 +15,9 @@
 #include <KFormat>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KShortcutsDialog>
 #include <KWindowConfig>
 #include <KWindowSystem>
-#include <KXmlGui/KShortcutsDialog>
 #include <QGuiApplication>
 #include <QMenu>
 #include <QQuickWindow>
@@ -646,5 +646,6 @@ void KalendarApplication::showIncidenceByUid(const QString &uid, const QDateTime
         window->raise();
     }
 }
-
-Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr);
+#ifndef UNITY_CMAKE_SUPPORT
+Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
+#endif
